All Classes and Interfaces
Class
Description
The
AbstractColumn is the default implementation for the
Column interface.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type Boolean.Provides an accessor for a
Column property.Provides a mutator for a
Column property.Provides a
Column property.A
ColumnFactory creates or retrieves a Column instances
identified by the provided key (name).
The
CsvRecordReader is an implementation of the RecordReader
interface and provides functionality to parse CSV input streams:The
CsvRecordWriter writes CSV-Data.THis implementation of the
CsvRecordReader assumes that for ease of
use we just want to handle String columns.DateColumn implements the Column with support for the
Date type and various default or custom date formats.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type Double.The Class ExceptionColumnImpl.
A
Field stores an attribute consisting of a key (name) and a value.A
Fields stores an attribute consisting of a key (name) and an array
of values.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type Float.The
FormattedColumn class enriches a Column with
rendering metrics (as of the ColumnSetupMetrics) mostly for
text-based output such as for generating output for a terminal / console.In case no order of the
FormattedColumn instances is explicitly
required (similar to a DB table or a spread sheet, in contrast to a CSV file)
then FormattedColumn instances are grouped by a
FormattedColumns set.A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the FormattedHeader.Provides an accessor for a
Header property.Provides a mutator for an header property.
Provides a mutator for a
Header property.Provides a
Header property.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type Integer.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type Object.The Enum PrintStackTrace.
Provides an accessor for a
Record property.Provides a mutator for a
Record property.Provides a
Record property.Extends the
Records with functionality for file based implementations
regarding header management and means to monitor the state of reading data.Provides an accessor for a
Records property.Provides a mutator for a
Records property.Provides a
Records property.The
RecordWriter writes data.Most generic
ColumnFactory for creating Column instances
managing instances of the (sub-)type String.Base exception for this artifact.
Base exception with a
Column.Base exception with a
Column and a related value.Base exception with a
Header.Base exception with a key (name).
Base runtime exception for the refcodes-tabular artifact.
Declarative syntactic sugar which may be statically imported in order to
allow declarative definitions for the tabular package's elements, e.g. for
creating
Header or Column instances or
CsvRecordReader (CsvStringRecordReader) or
CsvRecordWriter (CsvStringRecordWriter) instances.Utility for listing specific functionality.