Interface ColumnFactory<T>

Type Parameters:
T - The type managed by the Column.
All Superinterfaces:
org.refcodes.factory.LookupFactory<Column<T>,String>
All Known Implementing Classes:
BooleanColumnFactory, DoubleColumnFactory, FloatColumnFactory, IntColumnFactory, LongColumnFactory, ObjectColumnFactory, StringColumnFactory

public interface ColumnFactory<T> extends org.refcodes.factory.LookupFactory<Column<T>,String>
A ColumnFactory creates or retrieves a Column instances identified by the provided key (name). The kind of Column and the type managed by the Column is factory dependent.
  • Nested Class Summary

    Nested classes/interfaces inherited from interface org.refcodes.factory.LookupFactory

    org.refcodes.factory.LookupFactory.ConfigurableLookupFactory<T,TID,OPTS extends org.refcodes.factory.Options>
  • Method Summary

    Modifier and Type
    Method
    Description
    create(String aKey)
  • Method Details