Class ColumnMismatchException

All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.ValueAccessor<Object>, ColumnAccessor

public class ColumnMismatchException extends TabularException.ColumnException.ColumnValueException
Thrown in case a value was found in the e.g. in a Record of the wrong type than specified by a provided Column (of for example a Header).
See Also: