Interface Columns<T>

Type Parameters:
T - The type managed by the Columns.
All Superinterfaces:
org.refcodes.mixin.Clearable, Collection<Column<? extends T>>, ColumnRow<T,Column<? extends T>>, Iterable<Column<? extends T>>, org.refcodes.struct.Keys<String,Column<? extends T>>, org.refcodes.struct.Keys.MutableKeys<String,Column<? extends T>>

public interface Columns<T> extends ColumnRow<T,Column<? extends T>>
In case no order of the Column instances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) then Column instances are grouped by a Columns set.

Columns provide additional semantics to the Field instances stored in a Record.