Module org.refcodes.tabular
Package org.refcodes.tabular
Interface HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>
-
- Type Parameters:
T- The managed by the builder which implements theHeaderAccessor.HeaderBuilder.
- Enclosing interface:
- HeaderAccessor<T>
public static interface HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>Provides a mutator for an header property.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description TwithHeader(Header<T> aHeader)Sets theHeaderto use returns this builder as of the builder pattern.
-