Class HeaderMismatchException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.tabular.TabularException
org.refcodes.tabular.TabularException.KeyException
org.refcodes.tabular.HeaderMismatchException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.KeyAccessor<String>
Thrown in case there is a mismatch between the given
Header and a
Row (or another Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a Header.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.refcodes.tabular.TabularException
TabularException.ColumnException, TabularException.HeaderException, TabularException.KeyExceptionNested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K, B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K>, org.refcodes.mixin.KeyAccessor.KeyProperty<K> -
Field Summary
Fields inherited from class org.refcodes.tabular.TabularException.KeyException
_key -
Constructor Summary
ConstructorsConstructorDescriptionHeaderMismatchException(String aMessage, String aKey) Instantiates the classHeaderMismatchException.HeaderMismatchException(String aMessage, String aKey, String aErrorCode) Instantiates the classHeaderMismatchException.HeaderMismatchException(String aMessage, String aKey, Throwable aCause) Instantiates the classHeaderMismatchException.HeaderMismatchException(String aMessage, String aKey, Throwable aCause, String aErrorCode) Instantiates the classHeaderMismatchException.HeaderMismatchException(String aKey, Throwable aCause) Instantiates the classHeaderMismatchException.HeaderMismatchException(String aKey, Throwable aCause, String aErrorCode) Instantiates the classHeaderMismatchException. -
Method Summary
Methods inherited from class org.refcodes.tabular.TabularException.KeyException
getKey, getPatternArgumentsMethods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-
HeaderMismatchException
Instantiates the classHeaderMismatchException.- See Also:
-