- Type Parameters:
T- The type managed by theRows.
- All Superinterfaces:
HeaderAccessor<T>,Iterator<Row<T>>
- All Known Implementing Classes:
RowsImpl
A bunch of
Row instances is represented by a Rows instance.
As of efficiency reasons, a Rows instance can be iterated through,
returning a single Row within each iteration. This approach is making
it possible to query a DB in the background and just hold the Row
instances being served next in the Rows instance (in memory).
The way how Rows instances manage their related Row instances
is implementation specific, a plain java implementation might use some kind
of collection for storing the Row instances (this can get memory
intensive and not applicable when working with big data). A DB implementation
might retrieve the Row instances in blocks one by one, one after the
other, by querying the DB accordingly (in terms of "next" result sets).
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.tabular.HeaderAccessor
HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>, HeaderAccessor.HeaderMutator<T>, HeaderAccessor.HeaderProperty<T> -
Method Summary
Methods inherited from interface org.refcodes.tabular.HeaderAccessor
getHeaderMethods inherited from interface java.util.Iterator
forEachRemaining, hasNext, next, remove