Uses of Interface
org.refcodes.tabular.Column
-
Uses of Column in org.refcodes.tabular
Classes in org.refcodes.tabular with type parameters of type ColumnModifier and TypeClassDescriptionclassAbstractHeader<T, C extends Column<? extends T>>interfaceinterfaceClasses in org.refcodes.tabular that implement ColumnModifier and TypeClassDescriptionclassTheAbstractColumnis the default implementation for theColumninterface.classclassDateColumnimplements theColumnwith support for theDatetype and various default or custom date formats.classclassEnumColumn<T extends Enum<T>>classThe Class ExceptionColumnImpl.classclassTheFormattedColumnclass enriches aColumnwith rendering metrics (as of theColumnSetupMetrics) mostly for text-based output such as for generating output for a terminal / console.classclassclassObjectColumn<T>classclassSubclasses with type arguments of type Column in org.refcodes.tabularSubinterfaces with type arguments of type Column in org.refcodes.tabularModifier and TypeInterfaceDescriptioninterfaceAColumnFactorycreates or retrieves aColumninstances identified by the provided key (name).interfaceColumns<T>interfaceHeader<T>Fields in org.refcodes.tabular declared as ColumnMethods in org.refcodes.tabular that return ColumnModifier and TypeMethodDescriptionTabularSugar.booleanColumn(String aKey) Constructs aColumnwith support for boolean values.TabularSugar.dateColumn(String aKey) Constructs aColumnwith support for the defaultSimpleDateFormatinstances as defined in theDateFormats.DEFAULT_DATE_FORMATS.TabularSugar.dateColumn(String aKey, DateTimeFormatter... aDateFormats) Constructs aColumnwith support for the providedSimpleDateFormatinstances.TabularSugar.doubleColumn(String aKey) Constructs aColumnwith support for double values.TabularSugar.enumColumn(String aKey, Class<T> aType) Constructs aColumnwith support for enumeration values.TabularSugar.floatColumn(String aKey) Constructs aColumnwith support for float values.ColumnAccessor.getColumn()Retrieves theColumnproperty.Column<?> TabularException.ColumnException.getColumn()Retrieves theColumnproperty.Constructs aColumnwith support for integer values.This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumn(setter) as ofColumnAccessor.ColumnMutator.setColumn(Column)and returns the very same value (getter).TabularSugar.longColumn(String aKey) Constructs aColumnwith support for long values.TabularSugar.stringColumn(String aKey) Constructs aColumnwith support for string values.Methods in org.refcodes.tabular with parameters of type ColumnModifier and TypeMethodDescriptionstatic Header<?> This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumn(setter) as ofColumnAccessor.ColumnMutator.setColumn(Column)and returns the very same value (getter).CsvRecordReader.readHeader(Column<T>... aColumns) Creates aHeaderfrom the next line to be read.RecordReader.readHeader(Column<T>... aColumns) Creates aHeaderfrom the next line to be read.voidSets theColumnproperty.ColumnRow.withColumns(C... aColumns) With columns.Columns.withColumns(Column<? extends T>... aColumns) With columns.Constructors in org.refcodes.tabular with parameters of type ColumnModifierConstructorDescriptionAbstractHeader(C... aColumns) Constructs theAbstractHeaderinstance configured with the providedColumninstances.ColumnException(String aMessage, Column<?> aColumn) Instantiates the classTabularException.ColumnException.ColumnException(String aMessage, Column<?> aColumn, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnException(String aMessage, Column<?> aColumn, Throwable aCause) Instantiates the classTabularException.ColumnException.ColumnException(String aMessage, Column<?> aColumn, Throwable aCause, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnException(Column<?> aColumn, Throwable aCause) Instantiates the classTabularException.ColumnException.ColumnException(Column<?> aColumn, Throwable aCause, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnMismatchException(String aMessage, Column<?> aColumn, Object aValue) Instantiates the classColumnMismatchException.ColumnMismatchException(String aMessage, Column<?> aColumn, Object aValue, String aErrorCode) Instantiates the classColumnMismatchException.ColumnMismatchException(Column<?> aColumn, Object aValue, String aMessage, Throwable aCause) Instantiates the classColumnMismatchException.ColumnMismatchException(Column<?> aColumn, Object aValue, String aMessage, Throwable aCause, String aErrorCode) Instantiates the classColumnMismatchException.ColumnMismatchException(Column<?> aColumn, Object aValue, Throwable aCause) Instantiates the classColumnMismatchException.ColumnMismatchException(Column<?> aColumn, Object aValue, Throwable aCause, String aErrorCode) Instantiates the classColumnMismatchException.ColumnValueException(String aMessage, Column<?> aColumn, Object aValue) Instantiates the classTabularException.ColumnException.ColumnValueException.ColumnValueException(String aMessage, Column<?> aColumn, Object aValue, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnValueException.ColumnValueException(String aMessage, Column<?> aColumn, Object aValue, Throwable aCause) Instantiates the classTabularException.ColumnException.ColumnValueException.ColumnValueException(String aMessage, Column<?> aColumn, Object aValue, Throwable aCause, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnValueException.ColumnValueException(Column<?> aColumn, Object aValue, Throwable aCause) Instantiates the classTabularException.ColumnException.ColumnValueException.ColumnValueException(Column<?> aColumn, Object aValue, Throwable aCause, String aErrorCode) Instantiates the classTabularException.ColumnException.ColumnValueException.FormattedColumn(Column<T> aColumn) Wrapper for the providedColumndecorating it with additionalColumnSetupMetricsfunctionality.FormattedColumn(Column<T> aColumn, ColumnSetupMetrics aColumnSetupMetrics) Wrapper for the providedColumnand the providedColumnSetupMetricsdecorating it with each other's additional functionality.HeaderImpl(Column<? extends T>... aColumns) Instantiates the classHeaderImpl.