-
Retrieves a type correct value from the
Record identified by the
Column instance's key.
Retrieves a type correct value from the
Record identified by the
Column instance's key.
FormattedColumnDecorator.get(Record<?> aRecord)
Retrieves a type correct value from the
Record identified by the
Column instance's key.
This method retrieves a value from the
Row by taking the index of
the according column of this
Header of the given key (the one
with the given key) and returns that value.
This method retrieves a value from the row by taking the index of the
according column in the header of the given key (the one with the given
key) and returns that value.
This method retrieves a value from the row by taking the index of the
according column in the header of the given key (the one with the given
key) and returns that value.
Removes an entry (key and value pair) from the provided
Record
matching the key and the type of the
Column.
Removes an entry (key and value pair) from the provided
Record
matching the key and the type of the
Column.
Removes an entry (key and value pair) from the provided
Record
matching the key and the type of the
Column.
Returns a
Record just containing the keys as defined in the
Header and found in the provided
Record.
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
Returns a
Record just containing the keys as defined in the
Header; keys not found in the provided
Record are
ignored.
void
Directly logs the provided
String instances to the writer.
void
Directly logs the provided
String instances to the writer.
default <TYPE> void
Directly writes the provided instance to the writer.