Uses of Interface
org.refcodes.tabular.Field
-
-
Uses of Field in org.refcodes.tabular
Subinterfaces of Field in org.refcodes.tabular Modifier and Type Interface Description interfaceFields<T>AFieldsstores an attribute consisting of a key (name) and an array of values.Classes in org.refcodes.tabular that implement Field Modifier and Type Class Description classFieldImpl<T>classFieldsImpl<T>Methods in org.refcodes.tabular that return types with arguments of type Field Modifier and Type Method Description Set<Field<T>>Record. toFieldSet()Set<Field<T>>RecordImpl. toFieldSet()Constructors in org.refcodes.tabular with parameters of type Field Constructor Description RecordImpl(Field<? extends T>... aFields)Constructs theRecordImplinstance configured with the providedFieldinstances.Constructor parameters in org.refcodes.tabular with type arguments of type Field Constructor Description RecordImpl(List<Field<T>> aFields)Constructs a record with the given items.
-