Uses of Class
org.refcodes.tabular.FormattedColumn
-
Uses of FormattedColumn in org.refcodes.tabular
Subclasses with type arguments of type FormattedColumn in org.refcodes.tabularModifier and TypeClassDescriptionclassA list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theFormattedHeader.Subinterfaces with type arguments of type FormattedColumn in org.refcodes.tabularModifier and TypeInterfaceDescriptioninterfaceIn case no order of theFormattedColumninstances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) thenFormattedColumninstances are grouped by aFormattedColumnsset.Methods in org.refcodes.tabular with parameters of type FormattedColumnModifier and TypeMethodDescriptiondefault FormattedColumns<T> FormattedColumns.withColumns(FormattedColumn<? extends T>... aColumns) With columns.Constructors in org.refcodes.tabular with parameters of type FormattedColumnModifierConstructorDescriptionFormattedHeader(FormattedColumn<? extends T>... aHeader) Instantiates the classFormattedHeader.