Uses of Interface
org.refcodes.tabular.HeaderAccessor
-
Uses of HeaderAccessor in org.refcodes.tabular
Subinterfaces of HeaderAccessor in org.refcodes.tabularModifier and TypeInterfaceDescriptionstatic interfaceProvides aHeaderproperty.interfaceRecordReader<T>Extends theRecordswith functionality for file based implementations regarding header management and means to monitor the state of reading data.interfaceRecordWriter<T>TheRecordWriterwrites data.interfaceRows<T>Classes in org.refcodes.tabular that implement HeaderAccessorModifier and TypeClassDescriptionclassTheCsvRecordReaderis an implementation of theRecordReaderinterface and provides functionality to parse CSV input streams:classTheCsvRecordWriterwrites CSV-Data.classTHis implementation of theCsvRecordReaderassumes that for ease of use we just want to handleStringcolumns.classclassRowsImpl<T>protected static classBase exception with aHeader.