This method retrieves a value from the Row by taking the index of
the according column of this Header of the given key (the one
with the given key) and returns that value.
This method retrieves a value from the row by taking the index of the
according column in the header of the given key (the one with the given
key) and returns that value.
This method retrieves a value from the row by taking the index of the
according column in the header of the given key (the one with the given
key) and returns that value.
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
Similar to HeaderRow.toRecord(Row) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
Similar to HeaderRow.toRecord(Row) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
Similar to HeaderRow.toRow(Record) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
Similar to HeaderRow.toRow(Record) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).