A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
Similar to HeaderRow.toRow(Record) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
Similar to HeaderRow.toRow(Record) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
This method retrieves a value from the Row by taking the index of
the according column of this Header of the given key (the one
with the given key) and returns that value.
Tests whether the given potential Header equal set is matching
the Row's elements in terms of matching the same relevant
attributes of the Header with the elements in the Row.
Tests whether this Header is a subset of the Row's
elements in terms of matching the same relevant attributes of the
Header with the elements in the Row.
Tests whether the Row's elements is matching the given potential
Header superset in terms of matching the same relevant attributes
of the Header with the elements in the Row.
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
Similar to HeaderRow.toRecord(Row) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).
Similar to HeaderRow.toRecord(Row) with the difference that conversion is
done ignoring the type of the HeaderRowColumn instances
and the according value(s).