-
class
Thrown in case a value was found in the e.g. in a
Record of the wrong
type than specified by a provided
Column (of for example a
Header).
class
Thrown in case there is a mismatch between the given
Header and a
Row (or another
Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a
Header.
protected static class
protected static class
Base exception with a
Column and a related value.
protected static class
protected static class
Base exception with a key (name).