Package org.refcodes.tabular
package org.refcodes.tabular
This archetype helps processing table like data structures including the
processing of
CSV files
with records, headers as well as comments whilst supporting
Plain old Java
objects (POJO) and simple new Java
record types.
Please refer to the refcodes-tabular: Process tabular data and CSV files using POJOs documentation for an up-to-date and detailed description on the usage of this artifact.
-
ClassDescriptionThe
AbstractColumnis the default implementation for theColumninterface.AbstractHeader<T, C extends Column<? extends T>>Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeBoolean.Column<T>Provides an accessor for aColumnproperty.Provides a mutator for aColumnproperty.Provides aColumnproperty.AColumnFactorycreates or retrieves aColumninstances identified by the provided key (name).Columns<T>TheCsvRecordReaderis an implementation of theRecordReaderinterface and provides functionality to parse CSV input streams:TheCsvRecordWriterwrites CSV-Data.THis implementation of theCsvRecordReaderassumes that for ease of use we just want to handleStringcolumns.DateColumnimplements theColumnwith support for theDatetype and various default or custom date formats.Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeDouble.EnumColumn<T extends Enum<T>>The Class ExceptionColumnImpl.Field<T>AFieldstores an attribute consisting of a key (name) and a value.FieldImpl<T>Fields<T>AFieldsstores an attribute consisting of a key (name) and an array of values.FieldsImpl<T>Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeFloat.TheFormattedColumnclass enriches aColumnwith rendering metrics (as of theColumnSetupMetrics) mostly for text-based output such as for generating output for a terminal / console.In case no order of theFormattedColumninstances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) thenFormattedColumninstances are grouped by aFormattedColumnsset.A list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theFormattedHeader.Header<T>Provides an accessor for aHeaderproperty.HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>Provides a mutator for an header property.Provides a mutator for aHeaderproperty.Provides aHeaderproperty.HeaderImpl<T>Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeInteger.ObjectColumn<T>Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeObject.The Enum PrintStackTrace.Record<T>Provides an accessor for aRecordproperty.Provides a mutator for aRecordproperty.Provides aRecordproperty.RecordImpl<T>RecordReader<T>Extends theRecordswith functionality for file based implementations regarding header management and means to monitor the state of reading data.Records<T>Provides an accessor for aRecordsproperty.Provides a mutator for aRecordsproperty.Provides aRecordsproperty.RecordsImpl<T>RecordWriter<T>TheRecordWriterwrites data.Row<T>RowImpl<T>Rows<T>RowsImpl<T>Most genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeString.Base exception for this artifact.Base exception with aColumn.Base exception with aColumnand a related value.Base exception with aHeader.Base exception with a key (name).Base runtime exception for the refcodes-tabular artifact.Declarative syntactic sugar which may be statically imported in order to allow declarative definitions for the tabular package's elements, e.g. for creatingHeaderorColumninstances orCsvRecordReader(CsvStringRecordReader) orCsvRecordWriter(CsvStringRecordWriter) instances.Utility for listing specific functionality.