Similar to a Column definition for a DB or a spread sheet (or, with
reservations, a CSV file), a Column describes properties such as name
(key) and type of elements related to that Column (e.g. the according
elements of the Row lines).
In case no order of the Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a ColumnRow set.
In case no order of the Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a Columns set.
Enriches a Column with rendering metrics (as of the
ColumnSetupMetrics) mostly for text-based output such as for
generating output for a terminal / console.
In case no order of the FormattedColumn instances is explicitly
required (similar to a DB table or a spread sheet, in contrast to a CSV file)
then FormattedColumn instances are grouped by a
FormattedColumns set.
A list of Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the FormattedHeader.
A list of Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the Header.
Thrown in case there is a mismatch between the given Header and a
Row (or another Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a Header.
A list of Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the HeaderRow.