Class AbstractHeader<T,C extends Column<? extends T>>

  • Type Parameters:
    T - The type managed by the Header.
    C - the generic type
    All Implemented Interfaces:
    java.io.Serializable, java.lang.Cloneable, java.lang.Iterable<C>, java.util.Collection<C>, java.util.List<C>, java.util.RandomAccess, org.refcodes.structure.Clearable, org.refcodes.structure.Keys<java.lang.String,C>, org.refcodes.structure.Keys.MutableKeys<java.lang.String,C>, ColumnsTemplate<T,C>, HeaderTemplate<T,C>
    Direct Known Subclasses:
    FormattedHeaderImpl, HeaderImpl

    public abstract class AbstractHeader<T,C extends Column<? extends T>>
    extends java.util.ArrayList<C>
    implements HeaderTemplate<T,C>, java.lang.Cloneable
    Implementation of the Header interface being Cloneable.
    See Also:
    Serialized Form
    • Nested Class Summary

      • Nested classes/interfaces inherited from interface org.refcodes.structure.Keys

        org.refcodes.structure.Keys.MutableKeys<K extends java.lang.Object,V extends java.lang.Object>, org.refcodes.structure.Keys.MutableValues<K extends java.lang.Object,V extends java.lang.Object>
    • Field Summary

      • Fields inherited from class java.util.AbstractList

        modCount
    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      void add​(int aIndex, C aColumn)
      boolean add​(C aColumn)
      boolean containsKey​(java.lang.Object aKey)
      C delete​(java.lang.String aKey)
      Record<T> fromStorageString​(Record<java.lang.String> aStringRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<T> fromStorageString​(Row<java.lang.String> aStringRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<T> fromStorageStringRecord​(Record<java.lang.String> aStringRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      Record<T> fromStorageStringRow​(Row<java.lang.String> aStringRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      Record<T> fromStorageStrings​(Record<java.lang.String[]> aStringsRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<T> fromStorageStrings​(Row<java.lang.String[]> aStringsRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<T> fromStorageStringsRecord​(Record<java.lang.String[]> aStringsRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      Record<T> fromStorageStringsRow​(Row<java.lang.String[]> aStringsRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      C get​(java.lang.Object aKey)
      int indexOf​(java.lang.String aKey)
      Determines the index of the column with the given key or -1 if there is none such column.
      java.util.Set<java.lang.String> keySet()
      Record<java.lang.String> toPrintable​(Record<? extends T> aRecord)
      To printable.
      Row<java.lang.String> toPrintable​(Row<? extends T> aRow)
      To printable.
      Record<java.lang.String> toPrintableRecord​(Row<? extends T> aRow)
      A special Column implementation might provide its own printable format of the given objects; for example a human readable text representation of the value (or in very specialized cases even enriched with ANSI Escape-Codes).
      Row<java.lang.String> toPrintableRow​(Record<? extends T> aRecord)
      To printable row.
      Record<T> toRecord​(Row<? extends T> aRow)
      To record.
      Record<?> toRecordIgnoreType​(Row<?> aRow)
      Similar to HeaderTemplate.toRecord(Row) with the difference that conversion is done ignoring the type of the HeaderTemplate Column instances and the according value(s).
      Row<T> toRow​(Record<? extends T> aRecord)
      To row.
      Row<?> toRowIgnoreType​(Record<?> aRecord)
      Similar to HeaderTemplate.toRow(Record) with the difference that conversion is done ignoring the type of the HeaderTemplate Column instances and the according value(s).
      Record<java.lang.String> toStorageString​(Record<? extends T> aRecord)
      To storage string.
      Row<java.lang.String> toStorageString​(Row<? extends T> aRow)
      To storage string.
      Record<java.lang.String> toStorageStringRecord​(Row<? extends T> aRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<java.lang.String> toStorageStringRow​(Record<? extends T> aRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      Record<java.lang.String[]> toStorageStrings​(Record<? extends T> aRecord)
      To storage strings.
      Row<java.lang.String[]> toStorageStrings​(Row<? extends T> aRow)
      To storage strings.
      Record<java.lang.String[]> toStorageStringsRecord​(Row<? extends T> aRow)
      A special Column implementation might provide its own text exchange format for the given objects.
      Row<java.lang.String[]> toStorageStringsRow​(Record<? extends T> aRecord)
      A special Column implementation might provide its own text exchange format for the given objects.
      java.util.Collection<C> values()
      • Methods inherited from class java.util.AbstractCollection

        containsAll, toString
      • Methods inherited from class java.util.AbstractList

        equals, hashCode
      • Methods inherited from class java.util.ArrayList

        addAll, addAll, clear, clone, contains, ensureCapacity, forEach, get, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, removeIf, removeRange, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray, trimToSize
      • Methods inherited from interface org.refcodes.structure.Clearable

        clear
      • Methods inherited from interface java.util.Collection

        parallelStream, removeIf, stream
      • Methods inherited from interface java.lang.Iterable

        forEach
      • Methods inherited from interface org.refcodes.structure.Keys

        get, use
      • Methods inherited from interface java.util.List

        addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
      • Methods inherited from class java.lang.Object

        finalize, getClass, notify, notifyAll, wait, wait, wait