Package org.refcodes.tabular
Class DateColumnImpl
- java.lang.Object
-
- org.refcodes.tabular.AbstractColumn<java.util.Date>
-
- org.refcodes.tabular.DateColumnImpl
-
- All Implemented Interfaces:
java.lang.Cloneable,org.refcodes.mixin.KeyAccessor<java.lang.String>,org.refcodes.mixin.TypeAccessor<java.util.Date>,Column<java.util.Date>
public class DateColumnImpl extends AbstractColumn<java.util.Date> implements java.lang.Cloneable
DateColumnImplimplements theColumnwith support for theDatetype and various default or custom date formats.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends java.lang.Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K,B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends java.lang.Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends java.lang.Object>
-
-
Constructor Summary
Constructors Constructor Description DateColumnImpl(java.lang.String aKey)Constructor of theDateColumnImplwith support for the defaultSimpleDateFormatinstances as defined in theDateFormats.DEFAULT_DATE_FORMATS.DateColumnImpl(java.lang.String aKey, java.time.format.DateTimeFormatter[] aDateFormats)Constructor of theDateColumnImplwith support for the providedSimpleDateFormatinstances.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description java.lang.Objectclone()java.util.DatefromStorageStrings(java.lang.String[] aStringValues)AColumnimplementation can provide its own text exchange format for the given objects.java.lang.StringtoPrintable(java.util.Date aValue)AColumnimplementation can provide its own printable format of the given objects; for example a human readable text representation of the value (or in very specialized cases even enriched with ANSI escape codes).java.lang.String[]toStorageStrings(java.util.Date aValue)AColumnimplementation can provide its own text exchange format for the given objects.-
Methods inherited from class org.refcodes.tabular.AbstractColumn
contains, fromStorageString, get, getKey, getType, remove, toStorageString
-
-
-
-
Constructor Detail
-
DateColumnImpl
public DateColumnImpl(java.lang.String aKey)
Constructor of theDateColumnImplwith support for the defaultSimpleDateFormatinstances as defined in theDateFormats.DEFAULT_DATE_FORMATS.- Parameters:
aKey- The key to be used.
-
DateColumnImpl
public DateColumnImpl(java.lang.String aKey, java.time.format.DateTimeFormatter[] aDateFormats)Constructor of theDateColumnImplwith support for the providedSimpleDateFormatinstances.- Parameters:
aKey- The key to be used.aDateFormats- TheSimpleDateFormatinstances used for parsing date strings.
-
-
Method Detail
-
toStorageStrings
public java.lang.String[] toStorageStrings(java.util.Date aValue)
AColumnimplementation can provide its own text exchange format for the given objects. This method enables theColumnto convert a value of the given type to aStringarray and viaColumn.fromStorageStrings(String[])back to the value (bijective). This method supports data sinks (such as Amazon's SimpleDb) which provide dedicated support for multiple values in a row's entry: In case T is an array type, then the storageStringrepresentations of the elements in that array may be placed in dedicated entries of the returnedStringarray. In case T is not an array type then the returnedStringarray may contain just one value. In case data sinks (such as relational databases) are to be addressed which allow only a single value in a row's entry, then the methodColumn.toStorageString(Object)may be used instead.- Specified by:
toStorageStringsin interfaceColumn<java.util.Date>- Parameters:
aValue- the element to be converted to aStringarray.- Returns:
- The
Stringarray representation of the value.
-
fromStorageStrings
public java.util.Date fromStorageStrings(java.lang.String[] aStringValues) throws java.text.ParseExceptionAColumnimplementation can provide its own text exchange format for the given objects. This method enables theColumnto convert aStringarray value to a value of the given type and viaColumn.toStorageStrings(Object)back to theStringarray (bijective). This method supports data sinks (such as Amazon's SimpleDb) which provide dedicated support for multiple values in a row's entry: In case T is an array type, then the storageStringrepresentations of the elements in that array may be placed in dedicated entries of the providedStringarray. In case T is not an array type then the passedStringarray may contain just one value. In case data sinks (such as relational databases) are to be addressed which allow only a single value in a row's entry, then the methodColumn.fromStorageString(String)may be used instead.- Specified by:
fromStorageStringsin interfaceColumn<java.util.Date>- Parameters:
aStringValues- The value to be converted to a type instance.- Returns:
- The type representation of the value.
- Throws:
java.text.ParseException- in case parsing theStringwas not possible
-
toPrintable
public java.lang.String toPrintable(java.util.Date aValue)
AColumnimplementation can provide its own printable format of the given objects; for example a human readable text representation of the value (or in very specialized cases even enriched with ANSI escape codes). This method enables theColumnto convert a value of the given type to a human readable text. The human readable text, in comparison to the methodObject.toString()(orColumn.toStorageString(Object)) is not intended to be converted back to the actual value (not bijective). This method may be used aHeaderinstance's methodHeaderTemplate.toPrintable(Record).- Specified by:
toPrintablein interfaceColumn<java.util.Date>- Overrides:
toPrintablein classAbstractColumn<java.util.Date>- Parameters:
aValue- the element to be converted to a human readable text.- Returns:
- The human readable representation of the value.
-
clone
public java.lang.Object clone() throws java.lang.CloneNotSupportedException- Overrides:
clonein classAbstractColumn<java.util.Date>- Throws:
java.lang.CloneNotSupportedException
-
-