Package org.refcodes.tabular
Interface Header<T>
-
- Type Parameters:
T- The type managed by theHeader.
- All Superinterfaces:
org.refcodes.structure.Clearable,java.util.Collection<Column<? extends T>>,ColumnsTemplate<T,Column<? extends T>>,HeaderTemplate<T,Column<? extends T>>,java.lang.Iterable<Column<? extends T>>,org.refcodes.structure.Keys<java.lang.String,Column<? extends T>>,org.refcodes.structure.Keys.MutableKeys<java.lang.String,Column<? extends T>>,java.util.List<Column<? extends T>>
- All Known Implementing Classes:
HeaderImpl
public interface Header<T> extends HeaderTemplate<T,Column<? extends T>>
A list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theHeader. TheHeaderpreserves an order for a list ofColumninstances. AHeaderprovides the semantics for relatedRowinstances.The
Keys.keySet()method must provide a predictable order as ensured by theLinkedHashSetclass as of the ordered nature of theHeader.
-
-
Method Summary
-
Methods inherited from interface org.refcodes.tabular.ColumnsTemplate
containsValue, withColumns
-
Methods inherited from interface org.refcodes.tabular.HeaderTemplate
fromStorageString, fromStorageString, fromStorageStringRecord, fromStorageStringRow, fromStorageStrings, fromStorageStrings, fromStorageStringsRecord, fromStorageStringsRow, indexOf, toPrintable, toPrintable, toPrintableRecord, toPrintableRow, toRecord, toRecordIgnoreType, toRow, toRowIgnoreType, toStorageString, toStorageString, toStorageStringRecord, toStorageStringRow, toStorageStrings, toStorageStrings, toStorageStringsRecord, toStorageStringsRow
-
Methods inherited from interface org.refcodes.structure.Keys
containsKey, get, get, keySet, use, values
-
Methods inherited from interface java.util.List
add, add, addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
-