Interface InputStreamRecords<T>

  • Type Parameters:
    T - The type managed by the Records.
    All Superinterfaces:
    HeaderAccessor<T>, java.util.Iterator<Record<? extends T>>, Records<T>
    All Known Implementing Classes:
    CsvFileRecordsImpl, CsvInputStreamRecordsImpl

    public interface InputStreamRecords<T>
    extends Records<T>, HeaderAccessor<T>
    Extends the Records with means to monitor the state of file based implementations. Reading Record instances may cause problems but no abortion of an operation (if desired), the statistics of the problems may be reported by an implementation of this interface.
    • Method Detail

      • getErroneousRecordCount

        long getErroneousRecordCount()
        The number of erroneous records which were not read by the InputStreamRecords.
        Returns:
        the erroneous record count