Package org.refcodes.tabular
Interface Record<T>
-
- Type Parameters:
T- The type managed by theRecord.
- All Superinterfaces:
java.util.Map<java.lang.String,T>
- All Known Implementing Classes:
RecordImpl
public interface Record<T> extends java.util.Map<java.lang.String,T>ARecordis aMapcontainingFielddata structures with support forColumndefinitions. TheFieldinstances can be managed with the functionality provided by aColumn.A value can be retrieved from a
Recordby providing an accordingColumndefinition, which verifies the value type. Also values can be converted to and from the appropriate interchange and string formats by the accordingColumninstances.In contrast to a
Row, aRecordrelates the key (name) to its values. Similar to aRow, aRecordmakes use ofColumninstances (for example as provided by aHeaderor aHeaderinstance) to give the fields additional semantics.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description java.util.Set<Field<? extends T>>toFieldSet()
-