Package org.refcodes.tabular
Interface Records<T>
-
- Type Parameters:
T- The type managed by theRecords.
- All Superinterfaces:
java.util.Iterator<Record<? extends T>>
- All Known Subinterfaces:
InputStreamRecords<T>
- All Known Implementing Classes:
CompositeRecordsImpl,CsvFileRecordsImpl,CsvInputStreamRecordsImpl,RecordsImpl
public interface Records<T> extends java.util.Iterator<Record<? extends T>>
A bunch ofRecordinstances is represented by aRecordsinstance. As of efficiency reasons, aRecordsinstance can be iterated through, returning a singleRecordwithin each iteration. This approach is making it possible to query a DB in the background and just hold theRecordinstances being served next in theRecordsinstance (in memory).The way how
Recordsinstances manage their relatedRecordinstances is implementation specific, a plain java implementation might use some kind of collection for storing theRecordinstances (this can get memory intensive and not applicable when working with big data). A DB implementation might retrieve theRecordinstances in blocks one by one, one after the other, by querying the DB accordingly (in terms of "next" result sets).