Uses of Interface
org.refcodes.tabular.Column
-
-
Uses of Column in org.refcodes.tabular
Classes in org.refcodes.tabular with type parameters of type Column Modifier and Type Class Description classAbstractHeader<T,C extends Column<? extends T>>Implementation of theHeaderinterface beingCloneable.interfaceColumnsTemplate<T,C extends Column<? extends T>>In case no order of theColumninstances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) thenColumninstances are grouped by aColumnsTemplateset.interfaceHeaderTemplate<T,C extends Column<? extends T>>A list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theHeaderTemplate.Subinterfaces of Column in org.refcodes.tabular Modifier and Type Interface Description interfaceFormattedColumn<T>Enriches aColumnwith rendering metrics (as of theColumnSetupMetrics) mostly for text-based output such as for generating output for a terminal / console.Classes in org.refcodes.tabular that implement Column Modifier and Type Class Description classAbstractColumn<T>TheAbstractColumnis the default implementation for theColumninterface.classColumnImpl<T>classDateColumnImplDateColumnImplimplements theColumnwith support for theDatetype and various default or custom date formats.classExceptionColumnImplThe Class ExceptionColumnImpl.classFormattedColumnDecorator<T>Decorator implementation of the HeaderSetupMetrics interface.classFormattedColumnImpl<T>Implementation of theFormattedColumninterface.classIntegerColumnImplclassStringColumnImplclassStringsColumnImplMethods in org.refcodes.tabular that return Column Modifier and Type Method Description Column<T>ColumnFactory. createInstance(java.lang.String aKey)Column<T>ColumnFactory. createInstance(java.lang.String aKey, java.util.Map<java.lang.String,java.lang.String> aProperties)Column<java.lang.Object>ColumnFactoryImpl. createInstance(java.lang.String aKey)Column<java.lang.Object>ColumnFactoryImpl. createInstance(java.lang.String aKey, java.util.Map<java.lang.String,java.lang.String> aProperties)Column<T>ColumnAccessor. getColumn()Retrieves theColumnproperty.Methods in org.refcodes.tabular with parameters of type Column Modifier and Type Method Description voidColumnAccessor.ColumnMutator. setColumn(Column<T> aColumn)Sets theColumnproperty.default Columns<T>Columns. withColumns(Column<? extends T>... aColumns)With columns.default ColumnsTemplate<T,C>ColumnsTemplate. withColumns(C... aColumns)With columns.Constructors in org.refcodes.tabular with parameters of type Column Constructor Description AbstractHeader(C... aHeader)Constructs theAbstractHeaderinstance configured with the providedColumninstances.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.String message)Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.String aMessage, java.lang.String aErrorCode)Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.String message, java.lang.Throwable cause)Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.String aMessage, java.lang.Throwable aCause, java.lang.String aErrorCode)Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.Throwable cause)Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, java.lang.Object aValue, java.lang.Throwable aCause, java.lang.String aErrorCode)Instantiates a new column mismatch exception.FormattedColumnDecorator(Column<T> aColumn)Wrapper for the providedColumndecorating it with additionalColumnSetupMetricsfunctionality.FormattedColumnDecorator(Column<T> aColumn, org.refcodes.textual.ColumnSetupMetrics aColumnSetupMetrics)Wrapper for the providedColumnand the providedColumnSetupMetricsdecorating it with each other's additional functionality.HeaderImpl(Column<? extends T>... aHeader)Instantiates a new header impl.
-