Uses of Interface
org.refcodes.tabular.ColumnFactory
-
-
Uses of ColumnFactory in org.refcodes.tabular
Classes in org.refcodes.tabular that implement ColumnFactory Modifier and Type Class Description classColumnFactoryImplMost genericColumnFactoryfor creatingColumninstances managing instances of the (sub-)typeObject.Methods in org.refcodes.tabular with parameters of type ColumnFactory Modifier and Type Method Description static <T> Header<T>TabularUtility. toHeader(java.lang.String[] aColumnKeys, ColumnFactory<T> aColumnFactory)Creates a header for a given string array with the column names to be used for the header.static <T> Header<T>TabularUtility. toHeader(java.util.Collection<java.lang.String> aColumnKeys, ColumnFactory<T> aColumnFactory)Creates a header for a given list of strings containing the column names to be used for the header.Constructors in org.refcodes.tabular with parameters of type ColumnFactory Constructor Description CsvFileRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.File aCsvFile)Constructs aCsvFileRecordsImplwith the given parameters.CsvFileRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.File aCsvFile, boolean isStrict)Constructs aCsvFileRecordsImplwith the given parameters.CsvFileRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.File aCsvFile, char aCsvSeparator)Constructs aCsvFileRecordsImplwith the given parameters.CsvFileRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.File aCsvFile, char aCsvSeparator, boolean isStrict)Constructs aCsvFileRecordsImplwith the given parameters.CsvInputStreamRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.InputStream aCsvInputStream)Constructs aCsvInputStreamRecordsImplwith the given parameters.CsvInputStreamRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.InputStream aCsvInputStream, boolean isStrict)Constructs aCsvInputStreamRecordsImplwith the given parameters.CsvInputStreamRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.InputStream aCsvInputStream, char aCsvDelimiter)Constructs aCsvInputStreamRecordsImplwith the given parameters.CsvInputStreamRecordsImpl(ColumnFactory<T> aColumnFactory, java.io.InputStream aCsvInputStream, char aCsvDelimiter, boolean isStrict)Constructs aCsvInputStreamRecordsImplwith the given parameters.CsvInputStreamRecordsImpl(Header<T> aHeader, ColumnFactory<T> aColumnFactory, java.io.InputStream aCsvInputStream, char aCsvDelimiter, boolean isStrict)Constructs aCsvInputStreamRecordsImplwith the given parameters.
-