Module org.refcodes.tabular
Package org.refcodes.tabular
Class AbstractHeader<T,C extends Column<? extends T>>
- java.lang.Object
-
- java.util.AbstractCollection<E>
-
- java.util.AbstractList<E>
-
- java.util.ArrayList<C>
-
- org.refcodes.tabular.AbstractHeader<T,C>
-
- Type Parameters:
T- The type managed by theHeader.C- the generic type
- All Implemented Interfaces:
Serializable,Cloneable,Iterable<C>,Collection<C>,List<C>,RandomAccess,org.refcodes.mixin.Clearable,org.refcodes.struct.Keys<String,C>,org.refcodes.struct.Keys.MutableKeys<String,C>,ColumnRow<T,C>,HeaderRow<T,C>
- Direct Known Subclasses:
FormattedHeader,HeaderImpl
public abstract class AbstractHeader<T,C extends Column<? extends T>> extends ArrayList<C> implements HeaderRow<T,C>, Cloneable
- See Also:
- Serialized Form
-
-
Field Summary
Fields Modifier and Type Field Description protected Set<String>_keysALinkedHashSetis used in order to preserve the order of the elements as contained in theHeaderitself.-
Fields inherited from class java.util.AbstractList
modCount
-
-
Constructor Summary
Constructors Constructor Description AbstractHeader()Constructs theAbstractHeaderinstance.AbstractHeader(C... aColumns)Constructs theAbstractHeaderinstance configured with the providedColumninstances.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voidadd(int aIndex, C aColumn)booleanadd(C aColumn)booleancontainsKey(Object aKey)Cdelete(String aKey)Record<T>fromStorageString(Record<String> aStringRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<T>fromStorageString(Row<String> aStringRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<T>fromStorageStringRecord(Record<String> aStringRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.Record<T>fromStorageStringRow(Row<String> aStringRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Record<T>fromStorageStrings(Record<String[]> aStringsRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<T>fromStorageStrings(Row<String[]> aStringsRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<T>fromStorageStringsRecord(Record<String[]> aStringsRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.Record<T>fromStorageStringsRow(Row<String[]> aStringsRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Cget(Object aKey)intindexOf(String aKey)Determines the index of the column with the given key or -1 if there is none such column.Set<String>keySet()Record<String>toPrintable(Record<? extends T> aRecord)To printable.Row<String>toPrintable(Row<? extends T> aRow)To printable.Record<String>toPrintableRecord(Row<? extends T> aRow)A specialColumnimplementation might provide its own printable format of the given objects; for example a human readable text representation of the value (or in very specialized cases even enriched with ANSI Escape-Codes).Row<String>toPrintableRow(Record<? extends T> aRecord)To printable row.Record<T>toRecord(Row<? extends T> aRow)To record.Record<?>toRecordIgnoreType(Row<?> aRow)Similar toHeaderRow.toRecord(Row)with the difference that conversion is done ignoring the type of theHeaderRowColumninstances and the according value(s).Row<T>toRow(Record<? extends T> aRecord)To row.Row<?>toRowIgnoreType(Record<?> aRecord)Similar toHeaderRow.toRow(Record)with the difference that conversion is done ignoring the type of theHeaderRowColumninstances and the according value(s).Record<String>toStorageString(Record<? extends T> aRecord)To storage string.Row<String>toStorageString(Row<? extends T> aRow)To storage string.Record<String>toStorageStringRecord(Row<? extends T> aRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<String>toStorageStringRow(Record<? extends T> aRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.Record<String[]>toStorageStrings(Record<? extends T> aRecord)To storage strings.Row<String[]>toStorageStrings(Row<? extends T> aRow)To storage strings.Record<String[]>toStorageStringsRecord(Row<? extends T> aRow)A specialColumnimplementation might provide its own text exchange format for the given objects.Row<String[]>toStorageStringsRow(Record<? extends T> aRecord)A specialColumnimplementation might provide its own text exchange format for the given objects.StringtoString()Collection<C>values()-
Methods inherited from class java.util.ArrayList
addAll, addAll, clear, clone, contains, ensureCapacity, equals, forEach, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, removeIf, removeRange, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray, trimToSize
-
Methods inherited from class java.util.AbstractCollection
containsAll
-
Methods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, wait
-
Methods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArray
-
Methods inherited from interface org.refcodes.tabular.ColumnRow
containsValue, withColumns
-
Methods inherited from interface java.util.List
addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
-
-
-
Field Detail
-
_keys
protected Set<String> _keys
ALinkedHashSetis used in order to preserve the order of the elements as contained in theHeaderitself.
-
-
Constructor Detail
-
AbstractHeader
public AbstractHeader()
Constructs theAbstractHeaderinstance.
-
AbstractHeader
@SafeVarargs public AbstractHeader(C... aColumns)
Constructs theAbstractHeaderinstance configured with the providedColumninstances.- Parameters:
aColumns- TheColumninstances to be contained in theAbstractHeaderin the order as passed.
-
-
Method Detail
-
containsKey
public boolean containsKey(Object aKey)
-
indexOf
public int indexOf(String aKey)
Determines the index of the column with the given key or -1 if there is none such column.
-
toStorageString
public Record<String> toStorageString(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
To storage string.- Specified by:
toStorageStringin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- the record- Returns:
- the record
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toStorageString
public Row<String> toStorageString(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
To storage string.- Specified by:
toStorageStringin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- the row- Returns:
- the row
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
fromStorageString
public Record<T> fromStorageString(Record<String> aStringRecord) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordcontaining onlyStringobjects to aRecordwith the given types and viaHeaderRow.toStorageString(Record)back to theStringRecord(bijective). This method may use aColumninstance's methodColumn.fromStorageString(String).- Specified by:
fromStorageStringin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringRecord- theStringRecordto be converted to a typeRecord.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenColumnsand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
fromStorageString
public Row<T> fromStorageString(Row<String> aStringRow) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowcontaining onlyStringobjects to aRowwith the given types and viaHeaderRow.toStorageString(Row)back to theStringRow(bijective). This method may use aColumninstance's methodColumn.fromStorageString(String).- Specified by:
fromStorageStringin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringRow- theStringRowto be converted to a typeRow.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toStorageStrings
public Record<String[]> toStorageStrings(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
To storage strings.- Specified by:
toStorageStringsin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- the record- Returns:
- the record
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toStorageStrings
public Row<String[]> toStorageStrings(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
To storage strings.- Specified by:
toStorageStringsin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- the row- Returns:
- the row
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
fromStorageStrings
public Row<T> fromStorageStrings(Row<String[]> aStringsRow) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowcontaining onlyStringobjects to aRowwith the given types and viaHeaderRow.toStorageStrings(Row)back to theStringarrayRow(bijective). This method may use aColumninstance's methodColumn.fromStorageStrings(String[]). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
fromStorageStringsin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringsRow- theStringarrayRowto be converted to a typeRow.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
fromStorageStrings
public Record<T> fromStorageStrings(Record<String[]> aStringsRecord) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordcontaining onlyStringobjects to aRecordwith the given types and viaHeaderRow.toStorageStrings(Record)back to theStringRecord(bijective). This method may use aColumninstance's methodColumn.fromStorageStrings(String[]). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
fromStorageStringsin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringsRecord- theStringarrayRecordto be converted to a typeRecord.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenColumnsand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toPrintable
public Record<String> toPrintable(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
To printable.- Specified by:
toPrintablein interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- the record- Returns:
- the record
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toPrintable
public Row<String> toPrintable(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
To printable.- Specified by:
toPrintablein interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- the row- Returns:
- the row
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toRow
public Row<T> toRow(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
To row.- Specified by:
toRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- the record- Returns:
- the row
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toRowIgnoreType
public Row<?> toRowIgnoreType(Record<?> aRecord) throws HeaderMismatchException
Similar toHeaderRow.toRow(Record)with the difference that conversion is done ignoring the type of theHeaderRowColumninstances and the according value(s).- Specified by:
toRowIgnoreTypein interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- TheRecordto use when creating theRow.- Returns:
- The
Rowaccording to theColumninstances of theHeaderRow. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.
-
toRecord
public Record<T> toRecord(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
To record.- Specified by:
toRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- the row- Returns:
- the record
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toRecordIgnoreType
public Record<?> toRecordIgnoreType(Row<?> aRow) throws HeaderMismatchException
Similar toHeaderRow.toRecord(Row)with the difference that conversion is done ignoring the type of theHeaderRowColumninstances and the according value(s).- Specified by:
toRecordIgnoreTypein interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- TheRecordto use when creating theRecord.- Returns:
- The
Rowaccording to theColumninstances of theHeaderRow. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.
-
fromStorageStringRecord
public Row<T> fromStorageStringRecord(Record<String> aStringRecord) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordcontaining onlyStringobjects to aRowwith the given types and viaHeaderRow.toStorageStringRecord(Row)back to theStringRecord(bijective). This method may use aColumninstance's methodColumn.fromStorageString(String).- Specified by:
fromStorageStringRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringRecord- theStringRecordto be converted to a typeRow.- Returns:
- The type
Rowrepresentation of theStringRecord. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toStorageStringRecord
public Record<String> toStorageStringRecord(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowof the given type to aRecordcontaining onlyStringvalues and viaHeaderRow.fromStorageStringRecord(Record)back to the actualRow(bijective). This method may use aColumninstance's methodColumn.toStorageString(Object).- Specified by:
toStorageStringRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- TheRowto be converted to aStringRecord.- Returns:
- The
Stringrepresentation of the value. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ColumnMismatchException- Thrown in case a value was found in the e.g. in aRowof the wrong type than specified by aColumnof theHeaderRow.
-
fromStorageStringRow
public Record<T> fromStorageStringRow(Row<String> aStringRow) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowcontaining onlyStringobjects to aRecordwith the given types and viaHeaderRow.toStorageStringRow(Record)back to theStringRow(bijective). This method may use aColumninstance's methodColumn.fromStorageString(String).- Specified by:
fromStorageStringRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringRow- theStringRowto be converted to a typeRecord.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toStorageStringRow
public Row<String> toStorageStringRow(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordof the given type to aRowcontaining onlyStringvalues and viaHeaderRow.fromStorageStringRecord(Record)back to the actualRecord(bijective). This method may use aColumninstance's methodColumn.toStorageString(Object).- Specified by:
toStorageStringRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- TheRowto be converted to aStringRecord.- Returns:
- The
Stringrepresentation of the value. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ColumnMismatchException- Thrown in case a value was found in the e.g. in aRecordof the wrong type than specified by aColumnof theHeaderRow.
-
fromStorageStringsRecord
public Row<T> fromStorageStringsRecord(Record<String[]> aStringsRecord) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordcontaining onlyStringarrays to aRowwith the given types and viaHeaderRow.toStorageStringsRecord(Row)back to theStringRecord(bijective). This method may use aColumninstance's methodColumn.fromStorageStrings(String[]). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
fromStorageStringsRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringsRecord- theStringRecordto be converted to a typeRow.- Returns:
- The type
Rowrepresentation of theStringRecord. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toStorageStringsRecord
public Record<String[]> toStorageStringsRecord(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowof the given type to aRecordcontaining onlyStringarrays and viaHeaderRow.fromStorageStringsRecord(Record)back to the actualRow(bijective). This method may use aColumninstance's methodColumn.toStorageStrings(Object). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
toStorageStringsRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- TheRowto be converted to aStringRecord.- Returns:
- The
Stringrepresentation of the value. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ColumnMismatchException- Thrown in case a value was found in the e.g. in aRowof the wrong type than specified by aColumnof theHeaderRow.
-
fromStorageStringsRow
public Record<T> fromStorageStringsRow(Row<String[]> aStringsRow) throws HeaderMismatchException, ParseException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRowcontaining onlyStringarrays to aRecordwith the given types and viaHeaderRow.toStorageStringsRow(Record)back to theStringRow(bijective). This method may use aColumninstance's methodColumn.fromStorageStrings(String[]). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
fromStorageStringsRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aStringsRow- theStringRowto be converted to a typeRecord.- Returns:
- The type representation of the value.
- Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ParseException- in case parsing the input was not possible
-
toStorageStringsRow
public Row<String[]> toStorageStringsRow(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
A specialColumnimplementation might provide its own text exchange format for the given objects. This method enables theHeaderRowto convert aRecordof the given type to aRowcontaining onlyStringarrays and viaHeaderRow.fromStorageStringsRecord(Record)back to the actualRecord(bijective). This method may use aColumninstance's methodColumn.toStorageStrings(Object). SupportingStringarrays enables to address data sinks which support multiple values in one filed (for example some NoSQL databases such as Amazon's simple DB supports multiple values in one row's entry).- Specified by:
toStorageStringsRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- TheRowto be converted to aStringRecord.- Returns:
- The
Stringrepresentation of the value. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ColumnMismatchException- Thrown in case a value was found in the e.g. in aRecordof the wrong type than specified by aColumnof theHeaderRow.
-
toPrintableRow
public Row<String> toPrintableRow(Record<? extends T> aRecord) throws HeaderMismatchException, ColumnMismatchException
To printable row.- Specified by:
toPrintableRowin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRecord- the record- Returns:
- the row
- Throws:
HeaderMismatchException- the header mismatch exceptionColumnMismatchException- the column mismatch exception
-
toPrintableRecord
public Record<String> toPrintableRecord(Row<? extends T> aRow) throws HeaderMismatchException, ColumnMismatchException
A specialColumnimplementation might provide its own printable format of the given objects; for example a human readable text representation of the value (or in very specialized cases even enriched with ANSI Escape-Codes). This method enables theHeaderRowto convert aRowof the given type to a human readable textRecord. The human readable text, in comparison to the methodHeaderRow.toStorageString(Row)(orHeaderRow.toRecordIgnoreType(Row)) is not intended to be converted back to the actual value (not bijective). This method may use aColumninstance's methodColumn.toPrintable(Object); it also might enrich the output of theColumn.toPrintable(Object)with device specific additional data such as ANSI Escape-Codes and with information regarding theRowas a whole and not just be regarding a single value.- Specified by:
toPrintableRecordin interfaceHeaderRow<T,C extends Column<? extends T>>- Parameters:
aRow- theRowto be converted to a human readable textRecord.- Returns:
- The human readable
Recordrepresentation of theRow. - Throws:
HeaderMismatchException- Thrown in case there is a mismatch between the givenHeaderMismatchExceptionand theRow, i.e. the index for the given key in the header may be out of index of the given row or the given key does not exist in theHeaderRow.ColumnMismatchException- Thrown in case a value was found in the e.g. in aRowof the wrong type than specified by aColumnof theHeaderRow.
-
add
public boolean add(C aColumn)
-
add
public void add(int aIndex, C aColumn)
-
values
public Collection<C> values()
-
-