Interface ColumnRow<T,​C extends Column<? extends T>>

Type Parameters:
T - The type managed by the ColumnRow.
C - the generic type
All Superinterfaces:
org.refcodes.mixin.Clearable, Collection<C>, Iterable<C>, org.refcodes.struct.Keys<String,​C>, org.refcodes.struct.Keys.MutableKeys<String,​C>
All Known Subinterfaces:
Columns<T>, FormattedColumns<T>, FormattedHeader<T>, Header<T>, HeaderRow<T,​C>
All Known Implementing Classes:
AbstractHeader, FormattedHeaderImpl, HeaderImpl

public interface ColumnRow<T,​C extends Column<? extends T>>
extends Collection<C>, org.refcodes.struct.Keys.MutableKeys<String,​C>
In case no order of the Column instances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) then Column instances are grouped by a ColumnRow set.

ColumnRow provide additional semantics to the Field instances stored in a Record.

  • Method Details

    • withColumns

      default ColumnRow<T,​C> withColumns​(C... aColumns)
      With columns.
      Parameters:
      aColumns - the columns
      Returns:
      the columns template
    • containsValue

      default boolean containsValue​(Object value)
      Specified by:
      containsValue in interface org.refcodes.struct.Keys<T,​C extends Column<? extends T>>