Class DateColumn

java.lang.Object
org.refcodes.tabular.AbstractColumn<Date>
org.refcodes.tabular.DateColumn
All Implemented Interfaces:
Cloneable, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.TypeAccessor<Date>, Column<Date>

public class DateColumn extends AbstractColumn<Date>
DateColumn implements the Column with support for the Date type and various default or custom date formats.