-
- Type Parameters:
T- The type managed by theFormattedHeader.
- All Superinterfaces:
org.refcodes.mixin.Clearable,Collection<FormattedColumn<? extends T>>,ColumnRow<T,FormattedColumn<? extends T>>,HeaderRow<T,FormattedColumn<? extends T>>,Iterable<FormattedColumn<? extends T>>,org.refcodes.struct.Keys<String,FormattedColumn<? extends T>>,org.refcodes.struct.Keys.MutableKeys<String,FormattedColumn<? extends T>>,List<FormattedColumn<? extends T>>
- All Known Implementing Classes:
FormattedHeaderImpl
public interface FormattedHeader<T> extends HeaderRow<T,FormattedColumn<? extends T>>
A list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theFormattedHeader. TheFormattedHeaderpreserves an order for a list ofColumninstances. AFormattedHeaderprovides the semantics for relatedRowinstances.The
Keys.keySet()method must provide a predictable order as ensured by theLinkedHashSetclass as of the ordered nature of theFormattedHeader.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Default Methods Modifier and Type Method Description StringgetResetEscapeCode()Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance.voidsetResetEscapeCode(String aEscapeCode)Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance.default FormattedHeader<T>withResetEscapeCode(String aEscapeCode)Sets the ANSI reset Escape-Code for thisFormattedHeaderinstance as of the Builder-Pattern.-
Methods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArray
-
Methods inherited from interface org.refcodes.tabular.ColumnRow
containsValue, withColumns
-
Methods inherited from interface org.refcodes.tabular.HeaderRow
fromStorageString, fromStorageString, fromStorageStringRecord, fromStorageStringRow, fromStorageStrings, fromStorageStrings, fromStorageStringsRecord, fromStorageStringsRow, indexOf, toPrintable, toPrintable, toPrintableRecord, toPrintableRow, toRecord, toRecord, toRecordIgnoreType, toRow, toRowIgnoreType, toStorageString, toStorageString, toStorageStringRecord, toStorageStringRow, toStorageStrings, toStorageStrings, toStorageStringsRecord, toStorageStringsRow
-
Methods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, values
-
Methods inherited from interface java.util.List
add, add, addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
-
-
-
Method Detail
-
getResetEscapeCode
String getResetEscapeCode()
Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance. In case an ANSI Escape-Codes is set, then this ANSI Reset-Code is prepended to the according text being printed.- Returns:
- The
Stringto be used for resetting ANSI escaping.
-
setResetEscapeCode
void setResetEscapeCode(String aEscapeCode)
Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance. In case an ANSI Escape-Codes is set, then this ANSI Reset-Code is prepended to the according text being printed.- Parameters:
aEscapeCode- TheStringto be used for resetting ANSI escaping.
-
withResetEscapeCode
default FormattedHeader<T> withResetEscapeCode(String aEscapeCode)
Sets the ANSI reset Escape-Code for thisFormattedHeaderinstance as of the Builder-Pattern. In case an ANSI Escape-Codes is set, then this ANSI Reset-Code is prepended to the according text being printed.- Parameters:
aEscapeCode- TheStringto be used for resetting ANSI escaping.- Returns:
- This
FormattedHeaderinstance to continue configuration.
-
-