java.lang.Object
java.util.AbstractCollection<E>
java.util.AbstractList<E>
java.util.ArrayList<C>
org.refcodes.tabular.AbstractHeader<T,FormattedColumn<? extends T>>
org.refcodes.tabular.FormattedHeaderImpl<T>
- Type Parameters:
T- the generic type
- All Implemented Interfaces:
Serializable,Cloneable,Iterable<FormattedColumn<? extends T>>,Collection<FormattedColumn<? extends T>>,List<FormattedColumn<? extends T>>,RandomAccess,org.refcodes.mixin.Clearable,org.refcodes.struct.Keys<String,FormattedColumn<? extends T>>,org.refcodes.struct.Keys.MutableKeys<String,FormattedColumn<? extends T>>,ColumnRow<T,FormattedColumn<? extends T>>,FormattedHeader<T>,HeaderRow<T,FormattedColumn<? extends T>>
public class FormattedHeaderImpl<T> extends AbstractHeader<T,FormattedColumn<? extends T>> implements FormattedHeader<T>
The Class FormattedHeaderImpl.
- See Also:
- Serialized Form
-
Nested Class Summary
-
Field Summary
Fields inherited from class org.refcodes.tabular.AbstractHeader
_keysFields inherited from class java.util.AbstractList
modCount -
Constructor Summary
Constructors Constructor Description FormattedHeaderImpl()Instantiates a new formatted header impl.FormattedHeaderImpl(FormattedColumn<? extends T>... aHeader)Instantiates a new formatted header impl. -
Method Summary
Modifier and Type Method Description StringgetResetEscapeCode()Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance.voidsetResetEscapeCode(String aEscapeCode)Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance.Methods inherited from class org.refcodes.tabular.AbstractHeader
add, add, containsKey, delete, fromStorageString, fromStorageString, fromStorageStringRecord, fromStorageStringRow, fromStorageStrings, fromStorageStrings, fromStorageStringsRecord, fromStorageStringsRow, get, indexOf, keySet, toPrintable, toPrintable, toPrintableRecord, toPrintableRow, toRecord, toRecordIgnoreType, toRow, toRowIgnoreType, toStorageString, toStorageString, toStorageStringRecord, toStorageStringRow, toStorageStrings, toStorageStrings, toStorageStringsRecord, toStorageStringsRow, valuesMethods inherited from class java.util.ArrayList
addAll, addAll, clear, clone, contains, ensureCapacity, equals, forEach, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, removeIf, removeRange, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray, trimToSizeMethods inherited from class java.util.AbstractCollection
containsAll, toStringMethods inherited from class java.lang.Object
finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.mixin.Clearable
clearMethods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArrayMethods inherited from interface org.refcodes.tabular.ColumnRow
containsValue, withColumnsMethods inherited from interface org.refcodes.tabular.FormattedHeader
withResetEscapeCodeMethods inherited from interface org.refcodes.tabular.HeaderRow
fromStorageString, fromStorageString, fromStorageStringRecord, fromStorageStringRow, fromStorageStrings, fromStorageStrings, fromStorageStringsRecord, fromStorageStringsRow, indexOf, toPrintable, toPrintable, toPrintableRecord, toPrintableRow, toRecord, toRecordIgnoreType, toRow, toRowIgnoreType, toStorageString, toStorageString, toStorageStringRecord, toStorageStringRow, toStorageStrings, toStorageStrings, toStorageStringsRecord, toStorageStringsRowMethods inherited from interface org.refcodes.struct.Keys
containsKey, get, getOr, keySet, use, valuesMethods inherited from interface org.refcodes.struct.Keys.MutableKeys
deleteMethods inherited from interface java.util.List
add, add, addAll, addAll, clear, contains, containsAll, equals, get, hashCode, indexOf, isEmpty, iterator, lastIndexOf, listIterator, listIterator, remove, remove, removeAll, replaceAll, retainAll, set, size, sort, spliterator, subList, toArray, toArray
-
Constructor Details
-
FormattedHeaderImpl
public FormattedHeaderImpl()Instantiates a new formatted header impl. -
FormattedHeaderImpl
Instantiates a new formatted header impl.- Parameters:
aHeader- the header
-
-
Method Details
-
getResetEscapeCode
Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance. In case an ANSI Escape-Codes is set, then this ANSI Reset-Code is prepended to the according text being printed.- Specified by:
getResetEscapeCodein interfaceFormattedHeader<T>- Returns:
- The
Stringto be used for resetting ANSI escaping.
-
setResetEscapeCode
Gets the ANSI reset Escape-Code for thisFormattedHeaderinstance. In case an ANSI Escape-Codes is set, then this ANSI Reset-Code is prepended to the according text being printed.- Specified by:
setResetEscapeCodein interfaceFormattedHeader<T>- Parameters:
aEscapeCode- TheStringto be used for resetting ANSI escaping.
-