Class HeaderMismatchException

java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap, org.refcodes.mixin.KeyAccessor<String>

public class HeaderMismatchException extends TabularException.KeyException
Thrown in case there is a mismatch between the given Header and a Row (or another Header), i.e. the index for the given key in a header may be out of index of a given row or the given key does not exist in a Header.
See Also: