java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.tabular.TabularException
org.refcodes.tabular.HeaderMismatchException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.KeyAccessor<String>
Thrown in case there is a mismatch between the given
Header and a
Row (or another Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a Header.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K, B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionHeaderMismatchException(String aKey, String aMessage) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String aMessage, String aErrorCode) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String aMessage, Throwable aCause) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, Throwable aCause) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, Throwable aCause, String aErrorCode) Instantiates a new header mismatch exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keyaMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
HeaderMismatchException
Instantiates a new header mismatch exception. -
HeaderMismatchException
Instantiates a new header mismatch exception. -
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keyaMessage- The aMessage describing this exception.
-
HeaderMismatchException
Instantiates a new header mismatch exception. -
HeaderMismatchException
Instantiates a new header mismatch exception.
-
-
Method Details
-
getKey
Gets the key.- Specified by:
getKeyin interfaceorg.refcodes.mixin.KeyAccessor<String>- Returns:
- the key
-