java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.tabular.TabularException
org.refcodes.tabular.HeaderMismatchException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap,org.refcodes.mixin.KeyAccessor<String>
Thrown in case there is a mismatch between the given
Header and a
Row (or another Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a Header.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodePropertyNested classes/interfaces inherited from interface org.refcodes.mixin.KeyAccessor
org.refcodes.mixin.KeyAccessor.KeyBuilder<K extends Object,B extends org.refcodes.mixin.KeyAccessor.KeyBuilder<K, B>>, org.refcodes.mixin.KeyAccessor.KeyMutator<K extends Object>, org.refcodes.mixin.KeyAccessor.KeyProperty<K extends Object> -
Constructor Summary
ConstructorsConstructorDescriptionHeaderMismatchException(String aKey, String message) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String aMessage, String aErrorCode) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String message, Throwable cause) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, Throwable cause) Instantiates a new header mismatch exception.HeaderMismatchException(String aKey, Throwable aCause, String aErrorCode) Instantiates a new header mismatch exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keyaMessage- the messageaErrorCode- the error code
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keyaMessage- the messageaCause- the causeaErrorCode- the error code
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keymessage- the messagecause- the cause
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keymessage- the message
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keyaCause- the causeaErrorCode- the error code
-
HeaderMismatchException
Instantiates a new header mismatch exception.- Parameters:
aKey- the keycause- the cause
-
-
Method Details
-
getKey
Gets the key.- Specified by:
getKeyin interfaceorg.refcodes.mixin.KeyAccessor<String>- Returns:
- the key
-