Class ObjectColumn<T>

java.lang.Object
org.refcodes.tabular.AbstractColumn<T>
org.refcodes.tabular.ObjectColumn<T>
Type Parameters:
T - The type managed by the Column.
All Implemented Interfaces:
Cloneable, org.refcodes.mixin.KeyAccessor<String>, org.refcodes.mixin.TypeAccessor<T>, Column<T>

public class ObjectColumn<T> extends AbstractColumn<T>
Implementation of a Column supporting Object instances, being Cloneable. The storage String instance is converted from and back using serialization; the serialized byte arrays are converted using base64 encoding to a String.