-
- Type Parameters:
T- The type managed by theRows.
- All Superinterfaces:
HeaderAccessor<T>,Iterator<Row<T>>
- All Known Implementing Classes:
RowsImpl
public interface Rows<T> extends HeaderAccessor<T>, Iterator<Row<T>>
A bunch ofRowinstances is represented by aRowsinstance. As of efficiency reasons, aRowsinstance can be iterated through, returning a singleRowwithin each iteration. This approach is making it possible to query a DB in the background and just hold theRowinstances being served next in theRowsinstance (in memory).The way how
Rowsinstances manage their relatedRowinstances is implementation specific, a plain java implementation might use some kind of collection for storing theRowinstances (this can get memory intensive and not applicable when working with big data). A DB implementation might retrieve theRowinstances in blocks one by one, one after the other, by querying the DB accordingly (in terms of "next" result sets).
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.tabular.HeaderAccessor
HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>, HeaderAccessor.HeaderMutator<T>, HeaderAccessor.HeaderProperty<T>
-
-
Method Summary
-
Methods inherited from interface org.refcodes.tabular.HeaderAccessor
getHeader
-
Methods inherited from interface java.util.Iterator
forEachRemaining, hasNext, next, remove
-
-