Uses of Interface
org.refcodes.tabular.Column
-
Uses of Column in org.refcodes.tabular
Classes in org.refcodes.tabular with type parameters of type ColumnModifier and TypeClassDescriptionclassAbstractHeader<T,C extends Column<? extends T>> interfaceinterfaceSubinterfaces of Column in org.refcodes.tabularModifier and TypeInterfaceDescriptioninterfaceEnriches aColumnwith rendering metrics (as of theColumnSetupMetrics) mostly for text-based output such as for generating output for a terminal / console.Classes in org.refcodes.tabular that implement ColumnModifier and TypeClassDescriptionclassTheAbstractColumnis the default implementation for theColumninterface.classclassDateColumnimplements theColumnwith support for theDatetype and various default or custom date formats.classclassEnumColumn<T extends Enum<T>>classThe Class ExceptionColumnImpl.classclassDecorator implementation of the HeaderSetupMetrics interface.classImplementation of theFormattedColumninterface.classclassclassObjectColumn<T>classclassMethods in org.refcodes.tabular that return ColumnModifier and TypeMethodDescriptionTabularSugar.booleanColumn(String aKey) Constructs aColumnwith support for boolean values.BooleanColumnFactory.createInstance(String aKey) BooleanColumnFactory.createInstance(String aKey, Map<String, String> aProperties) ColumnFactory.createInstance(String aKey) ColumnFactory.createInstance(String aKey, Map<String, String> aProperties) DoubleColumnFactory.createInstance(String aKey) DoubleColumnFactory.createInstance(String aKey, Map<String, String> aProperties) FloatColumnFactory.createInstance(String aKey) FloatColumnFactory.createInstance(String aKey, Map<String, String> aProperties) IntColumnFactory.createInstance(String aKey) IntColumnFactory.createInstance(String aKey, Map<String, String> aProperties) LongColumnFactory.createInstance(String aKey) LongColumnFactory.createInstance(String aKey, Map<String, String> aProperties) ObjectColumnFactory.createInstance(String aKey) ObjectColumnFactory.createInstance(String aKey, Map<String, String> aProperties) StringColumnFactory.createInstance(String aKey) StringColumnFactory.createInstance(String aKey, Map<String, String> aProperties) TabularSugar.dateColumn(String aKey) Constructs aColumnwith support for the defaultSimpleDateFormatinstances as defined in theDateFormats.DEFAULT_DATE_FORMATS.TabularSugar.dateColumn(String aKey, DateTimeFormatter... aDateFormats) Constructs aColumnwith support for the providedSimpleDateFormatinstances.TabularSugar.doubleColumn(String aKey) Constructs aColumnwith support for double values.TabularSugar.enumColumn(String aKey, Class<T> aType) Constructs aColumnwith support for enumeration values.TabularSugar.floatColumn(String aKey) Constructs aColumnwith support for float values.ColumnAccessor.getColumn()Retrieves theColumnproperty.Constructs aColumnwith support for integer values.This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumn(setter) as ofColumnAccessor.ColumnMutator.setColumn(Column)and returns the very same value (getter).TabularSugar.longColumn(String aKey) Constructs aColumnwith support for long values.TabularSugar.stringColumn(String aKey) Constructs aColumnwith support for string values.Methods in org.refcodes.tabular with parameters of type ColumnModifier and TypeMethodDescriptionstatic Header<?>This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenColumn(setter) as ofColumnAccessor.ColumnMutator.setColumn(Column)and returns the very same value (getter).CsvRecordReader.readHeader(Column<T>... aColumns) Creates aHeaderfrom the next line to be read.RecordReader.readHeader(Column<T>... aColumns) Creates aHeaderfrom the next line to be read.voidSets theColumnproperty.ColumnRow.withColumns(C... aColumns) With columns.Columns.withColumns(Column<? extends T>... aColumns) With columns.Constructors in org.refcodes.tabular with parameters of type ColumnModifierConstructorDescriptionAbstractHeader(C... aColumns) Constructs theAbstractHeaderinstance configured with the providedColumninstances.ColumnMismatchException(Column<?> aColumn, Object aValue, String message) Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, Object aValue, String aMessage, String aErrorCode) Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, Object aValue, String message, Throwable cause) Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, Object aValue, String aMessage, Throwable aCause, String aErrorCode) Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, Object aValue, Throwable cause) Instantiates a new column mismatch exception.ColumnMismatchException(Column<?> aColumn, Object aValue, Throwable aCause, String aErrorCode) Instantiates a new column mismatch exception.FormattedColumnDecorator(Column<T> aColumn) Wrapper for the providedColumndecorating it with additionalColumnSetupMetricsfunctionality.FormattedColumnDecorator(Column<T> aColumn, org.refcodes.textual.ColumnSetupMetrics aColumnSetupMetrics) Wrapper for the providedColumnand the providedColumnSetupMetricsdecorating it with each other's additional functionality.HeaderImpl(Column<? extends T>... aColumns)