-
Classes in org.refcodes.tabular with type parameters of type Column
| Modifier and Type |
Class |
Description |
class |
AbstractHeader<T,C extends Column<? extends T>> |
|
interface |
ColumnRow<T,C extends Column<? extends T>> |
In case no order of the Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a ColumnRow set.
|
interface |
HeaderRow<T,C extends Column<? extends T>> |
A list of Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the HeaderRow.
|
Subinterfaces of Column in org.refcodes.tabular
| Modifier and Type |
Interface |
Description |
interface |
FormattedColumn<T> |
Enriches a Column with rendering metrics (as of the
ColumnSetupMetrics) mostly for text-based output such as for
generating output for a terminal / console.
|
Constructors in org.refcodes.tabular with parameters of type Column
| Constructor |
Description |
AbstractHeader(C... aHeader) |
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
String message) |
Instantiates a new column mismatch exception.
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
String aMessage,
String aErrorCode) |
Instantiates a new column mismatch exception.
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
String message,
Throwable cause) |
Instantiates a new column mismatch exception.
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
String aMessage,
Throwable aCause,
String aErrorCode) |
Instantiates a new column mismatch exception.
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
Throwable cause) |
Instantiates a new column mismatch exception.
|
ColumnMismatchException(Column<?> aColumn,
Object aValue,
Throwable aCause,
String aErrorCode) |
Instantiates a new column mismatch exception.
|
FormattedColumnDecorator(Column<T> aColumn) |
Wrapper for the provided Column decorating it with additional
ColumnSetupMetrics functionality.
|
FormattedColumnDecorator(Column<T> aColumn,
org.refcodes.textual.ColumnSetupMetrics aColumnSetupMetrics) |
Wrapper for the provided Column and the provided
ColumnSetupMetrics decorating it with each other's additional
functionality.
|
HeaderImpl(Column<? extends T>... aHeader) |
Instantiates a new header.
|