-
interface
In case no order of the
Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a
Columns set.
interface
interface
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
Header.
interface
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
HeaderRow.
class
class
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
FormattedHeader.
class
class