Uses of Interface
org.refcodes.tabular.ColumnRow
-
-
Uses of ColumnRow in org.refcodes.tabular
Subinterfaces of ColumnRow in org.refcodes.tabular Modifier and Type Interface Description interfaceColumns<T>interfaceFormattedColumns<T>In case no order of theFormattedColumninstances is explicitly required (similar to a DB table or a spread sheet, in contrast to a CSV file) thenFormattedColumninstances are grouped by aFormattedColumnsset.interfaceHeader<T>interfaceHeaderRow<T,C extends Column<? extends T>>Classes in org.refcodes.tabular that implement ColumnRow Modifier and Type Class Description classAbstractHeader<T,C extends Column<? extends T>>classFormattedHeader<T>A list ofColumninstances, for example describing the elements of a CSV file (visually speaking the of the CSV file's header line), is represented by theFormattedHeader.classHeaderImpl<T>classStringHeaderMethods in org.refcodes.tabular that return ColumnRow Modifier and Type Method Description default ColumnRow<T,C>ColumnRow. withColumns(C... aColumns)With columns.
-