Uses of Enum Class
org.refcodes.tabular.PrintStackTrace
-
Uses of PrintStackTrace in org.refcodes.tabular
Methods in org.refcodes.tabular that return PrintStackTraceModifier and TypeMethodDescriptionstatic PrintStackTraceReturns the enum constant of this class with the specified name.static PrintStackTrace[]PrintStackTrace.values()Returns an array containing the constants of this enum class, in the order they are declared.Constructors in org.refcodes.tabular with parameters of type PrintStackTraceModifierConstructorDescriptionExceptionColumn(String aKey, PrintStackTrace aPrintStackTrace) Creates anExceptionColumnwhich can consider or omit the stack trace in its string representationAbstractColumn.toStorageString(Object).