Uses of Class
org.refcodes.tabular.PrintStackTrace
-
-
Uses of PrintStackTrace in org.refcodes.tabular
Methods in org.refcodes.tabular that return PrintStackTrace Modifier and Type Method Description static PrintStackTracePrintStackTrace. valueOf(String name)Returns the enum constant of this type with the specified name.static PrintStackTrace[]PrintStackTrace. values()Returns an array containing the constants of this enum type, in the order they are declared.Constructors in org.refcodes.tabular with parameters of type PrintStackTrace Constructor Description ExceptionColumn(String aKey, PrintStackTrace aPrintStackTrace)Creates anExceptionColumnwhich can consider or omit the stack trace in its string representationAbstractColumn.toStorageString(Object).
-