-
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
This method retrieves a value from the
Row by taking the index of
the according column of this
Header of the given key (the one
with the given key) and returns that value.
default boolean
Tests whether the given potential
Header equal set is matching
the
Row's elements in terms of matching the same relevant
attributes of the
Header with the elements in the
Row.
default boolean
Tests whether this
Header is a subset of the
Row's
elements in terms of matching the same relevant attributes of the
Header with the elements in the
Row.
default boolean
Tests whether the
Row's elements is matching the given potential
Header superset in terms of matching the same relevant attributes
of the
Header with the elements in the
Row.
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own printable format of the given objects; for example a human
readable text representation of the value (or in very
https://www.metacodes.proized cases even enriched with ANSI
Escape-Codes).
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
A https://www.metacodes.pro
Column implementation might provide
its own text exchange format for the given objects.
Constructs the
RowsImpl instance configured with the provided
Row instances and the provided
Header instance.
Constructs the
RowsImpl instance configured with the provided
Row instances and the provided
Header instance.