Row<T> |
AbstractHeader.fromStorageString(Row<String> aStringRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Row<T> |
HeaderRow.fromStorageString(Row<String> aStringRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<T> |
AbstractHeader.fromStorageStringRow(Row<String> aStringRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<T> |
HeaderRow.fromStorageStringRow(Row<String> aStringRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Row<T> |
AbstractHeader.fromStorageStrings(Row<String[]> aStringsRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Row<T> |
HeaderRow.fromStorageStrings(Row<String[]> aStringsRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<T> |
AbstractHeader.fromStorageStringsRow(Row<String[]> aStringsRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<T> |
HeaderRow.fromStorageStringsRow(Row<String[]> aStringsRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
default T |
Header.get(Row<T> aRow,
String aKey) |
This method retrieves a value from the Row by taking the index of
the according column of this Header of the given key (the one
with the given key) and returns that value.
|
default boolean |
Header.isEqualWith(Row<?> aRow) |
Tests whether the given potential Header equal set is matching
the Row's elements in terms of matching the same relevant
attributes of the Header with the elements in the Row.
|
default boolean |
Header.isSubsetOf(Row<?> aRow) |
Tests whether this Header is a subset of the Row's
elements in terms of matching the same relevant attributes of the
Header with the elements in the Row.
|
default boolean |
Header.isSupersetOf(Row<?> aRow) |
Tests whether the Row's elements is matching the given potential
Header superset in terms of matching the same relevant attributes
of the Header with the elements in the Row.
|
Row<String> |
AbstractHeader.toPrintable(Row<? extends T> aRow) |
To printable.
|
Row<String> |
HeaderRow.toPrintable(Row<? extends T> aRow) |
A special Column implementation might provide its own printable
format of the given objects; for example a human readable text
representation of the value (or in very specialized cases even enriched
with ANSI Escape-Codes).
|
Record<String> |
AbstractHeader.toPrintableRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own printable
format of the given objects; for example a human readable text
representation of the value (or in very specialized cases even enriched
with ANSI Escape-Codes).
|
Record<String> |
HeaderRow.toPrintableRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own printable
format of the given objects; for example a human readable text
representation of the value (or in very specialized cases even enriched
with ANSI Escape-Codes).
|
Record<T> |
AbstractHeader.toRecord(Row<? extends T> aRow) |
To record.
|
Record<T> |
HeaderRow.toRecord(Row<? extends T> aRow) |
|
Record<?> |
AbstractHeader.toRecordIgnoreType(Row<?> aRow) |
|
Record<?> |
HeaderRow.toRecordIgnoreType(Row<?> aRow) |
|
Row<String> |
AbstractHeader.toStorageString(Row<? extends T> aRow) |
To storage string.
|
Row<String> |
HeaderRow.toStorageString(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<String> |
AbstractHeader.toStorageStringRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<String> |
HeaderRow.toStorageStringRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Row<String[]> |
AbstractHeader.toStorageStrings(Row<? extends T> aRow) |
To storage strings.
|
Row<String[]> |
HeaderRow.toStorageStrings(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<String[]> |
AbstractHeader.toStorageStringsRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|
Record<String[]> |
HeaderRow.toStorageStringsRecord(Row<? extends T> aRow) |
A special Column implementation might provide its own text
exchange format for the given objects.
|