-
Similar to a
Column definition for a DB or a spread sheet (or, with
reservations, a CSV file), a
Column describes properties such as name
(key) and type of elements related to that
Column (e.g. the according
elements of the
Row lines).
Provides an accessor for a
Column property.
Provides a mutator for a
Column property.
Thrown in case a value was found in the e.g. in a
Record of the wrong
type than specified by a provided
Column (of for example a
Header).
In case no order of the
Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a
ColumnRow set.
In case no order of the
Column instances is explicitly required
(similar to a DB table or a spread sheet, in contrast to a CSV file) then
Column instances are grouped by a
Columns set.
The
CsvRecordReader is an implementation of the
RecordReader
interface and provides functionality to parse CSV input streams:
Column<Float> floatColumn = floatColumn( "volume" );
Column<String> stringColumn = floatColumn( "name" );
Column<Integer> intColumn = floatColumn( "length" );
Column<Date> dateColumn = floatColumn( "time" );
try (CsvRecordReader<?
THis implementation of the
CsvRecordReader assumes that for ease of
use we just want to handle
String columns.
A
Field stores an attribute consisting of a key (name) and a value.
A
Fields stores an attribute consisting of a key (name) and an array
of values.
Enriches a
Column with rendering metrics (as of the
ColumnSetupMetrics) mostly for text-based output such as for
generating output for a terminal / console.
Decorator implementation of the HeaderSetupMetrics interface.
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
FormattedHeader.
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
Header.
Provides an accessor for a
Header property.
Provides a mutator for an header property.
Provides a mutator for a
Header property.
Thrown in case there is a mismatch between the given
Header and a
Row (or another
Header), i.e. the index for the given key in
a header may be out of index of a given row or the given key does not exist
in a
Header.
A list of
Column instances, for example describing the elements of a
CSV file (visually speaking the of the CSV file's header line), is
represented by the
HeaderRow.
The Enum PrintStackTrace.
Provides an accessor for a
Record property.
Provides a mutator for a
Record property.
Extends the
Records with functionality for file based implementations
regarding header management and means to monitor the state of reading data.
A bunch of
Record instances is represented by a
Records
instance.
Provides an accessor for a
Records property.
Provides a mutator for a
Records property.
A
Row holds multiple data elements loosely coupled to a
Header.
A bunch of
Row instances is represented by a
Rows instance.
Base exception for this artifact.
Base exception with a
Column and a related value.
Base exception with a key (name).