Package org.refcodes.tabular
Interface InputStreamRecords<T>
-
- Type Parameters:
T- The type managed by theRecords.
- All Superinterfaces:
HeaderAccessor<T>,java.util.Iterator<Record<? extends T>>,Records<T>
- All Known Implementing Classes:
CsvFileRecordsImpl,CsvInputStreamRecordsImpl
public interface InputStreamRecords<T> extends Records<T>, HeaderAccessor<T>
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.tabular.HeaderAccessor
HeaderAccessor.HeaderBuilder<T extends HeaderAccessor.HeaderBuilder<?>>, HeaderAccessor.HeaderMutator<T>, HeaderAccessor.HeaderProperty<T>
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description longgetErroneousRecordCount()The number of erroneous records which were not read by theInputStreamRecords.-
Methods inherited from interface org.refcodes.tabular.HeaderAccessor
getHeader
-
-
-
-
Method Detail
-
getErroneousRecordCount
long getErroneousRecordCount()
The number of erroneous records which were not read by theInputStreamRecords.- Returns:
- the erroneous record count
-
-